pub struct DirectiveSeed {
pub content: String,
pub is_active: bool,
pub name: String,
pub priority: i64,
}Expand description
A directive to create when bootstrapping a bank from a template.
JSON schema
{
"title": "DirectiveSeed",
"description": "A directive to create when bootstrapping a bank from a template.",
"type": "object",
"required": [
"content",
"name"
],
"properties": {
"content": {
"title": "Content",
"type": "string"
},
"is_active": {
"title": "Is Active",
"default": true,
"type": "boolean"
},
"name": {
"title": "Name",
"type": "string"
},
"priority": {
"title": "Priority",
"default": 0,
"type": "integer"
}
}
}Fields
content: Stringis_active: boolname: Stringpriority: i64Trait Implementations
Sourceimpl Clone for DirectiveSeed
impl Clone for DirectiveSeed
Sourcefn clone(&self) -> DirectiveSeed
fn clone(&self) -> DirectiveSeed
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DirectiveSeed
impl Debug for DirectiveSeed
Sourceimpl<'de> Deserialize<'de> for DirectiveSeed
impl<'de> Deserialize<'de> for DirectiveSeed
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&DirectiveSeed> for DirectiveSeed
impl From<&DirectiveSeed> for DirectiveSeed
Sourcefn from(value: &DirectiveSeed) -> Self
fn from(value: &DirectiveSeed) -> Self
Converts to this type from the input type.