pub struct EntityLabel {
pub description: String,
pub key: String,
pub optional: bool,
pub tag: bool,
pub type_: String,
pub values: Vec<EntityLabelValue>,
}Expand description
An entity label definition for structured classification.
Hindsight supports three label types:
- “value”: single enum value from the values list
- “multi-values”: multiple enum values from the values list
- “text”: free-form text (no values list needed)
The tag field controls whether facts with this label also get tagged
(enabling tag-based filtering in recall/reflect).
JSON schema
{
"title": "EntityLabel",
"description": "An entity label definition for structured classification.\n\nHindsight supports three label types:\n- \"value\": single enum value from the values list\n- \"multi-values\": multiple enum values from the values list\n- \"text\": free-form text (no values list needed)\n\nThe ``tag`` field controls whether facts with this label also get tagged\n(enabling tag-based filtering in recall/reflect).",
"type": "object",
"required": [
"key"
],
"properties": {
"description": {
"title": "Description",
"default": "",
"type": "string"
},
"key": {
"title": "Key",
"type": "string"
},
"optional": {
"title": "Optional",
"default": true,
"type": "boolean"
},
"tag": {
"title": "Tag",
"default": false,
"type": "boolean"
},
"type": {
"title": "Type",
"default": "value",
"type": "string"
},
"values": {
"title": "Values",
"type": "array",
"items": {
"$ref": "#/components/schemas/EntityLabelValue"
}
}
}
}Fields
description: Stringkey: Stringoptional: booltag: booltype_: Stringvalues: Vec<EntityLabelValue>Trait Implementations
Sourceimpl Clone for EntityLabel
impl Clone for EntityLabel
Sourcefn clone(&self) -> EntityLabel
fn clone(&self) -> EntityLabel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntityLabel
impl Debug for EntityLabel
Sourceimpl<'de> Deserialize<'de> for EntityLabel
impl<'de> Deserialize<'de> for EntityLabel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&EntityLabel> for EntityLabel
impl From<&EntityLabel> for EntityLabel
Sourcefn from(value: &EntityLabel) -> Self
fn from(value: &EntityLabel) -> Self
Converts to this type from the input type.