pub struct UpdateSelfServiceAccountRequest {
pub display_name: String,
}Expand description
Self-service SA update — only display_name is mutable.
Scoping policy and activation state are admin-only operations. An SA authenticates as its owner, so without this restriction an SA could remove its own scoping policy and escalate to the parent user’s full permissions.
JSON schema
{
"title": "UpdateSelfServiceAccountRequest",
"description": "Self-service SA update — only display_name is mutable.\n\nScoping policy and activation state are admin-only operations.\nAn SA authenticates as its owner, so without this restriction an SA\ncould remove its own scoping policy and escalate to the parent user's\nfull permissions.",
"type": "object",
"required": [
"display_name"
],
"properties": {
"display_name": {
"title": "Display Name",
"type": "string"
}
},
"additionalProperties": false
}Fields
display_name: StringTrait Implementations
Sourceimpl Clone for UpdateSelfServiceAccountRequest
impl Clone for UpdateSelfServiceAccountRequest
Sourcefn clone(&self) -> UpdateSelfServiceAccountRequest
fn clone(&self) -> UpdateSelfServiceAccountRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdateSelfServiceAccountRequest
impl<'de> Deserialize<'de> for UpdateSelfServiceAccountRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&UpdateSelfServiceAccountRequest> for UpdateSelfServiceAccountRequest
impl From<&UpdateSelfServiceAccountRequest> for UpdateSelfServiceAccountRequest
Sourcefn from(value: &UpdateSelfServiceAccountRequest) -> Self
fn from(value: &UpdateSelfServiceAccountRequest) -> Self
Converts to this type from the input type.