UpdateTemplateRequest

Struct UpdateTemplateRequest 

pub struct UpdateTemplateRequest {
Show 24 fields pub author: Option<String>, pub consolidation_llm_batch_size: Option<NonZeroU64>, pub consolidation_source_facts_max_tokens: Option<i64>, pub consolidation_source_facts_max_tokens_per_observation: Option<i64>, pub description: Option<String>, pub directive_seeds: Option<Vec<DirectiveSeed>>, pub disposition_empathy: Option<NonZeroU64>, pub disposition_literalism: Option<NonZeroU64>, pub disposition_skepticism: Option<NonZeroU64>, pub enable_observations: Option<bool>, pub entities_allow_free_form: Option<bool>, pub entity_labels: Option<Vec<EntityLabel>>, pub mental_model_seeds: Option<Vec<MentalModelSeed>>, pub min_hindclaw_version: Option<String>, pub min_hindsight_version: Option<String>, pub observations_mission: Option<String>, pub reflect_mission: Option<String>, pub retain_chunk_size: Option<NonZeroU64>, pub retain_custom_instructions: Option<String>, pub retain_default_strategy: Option<String>, pub retain_extraction_mode: Option<String>, pub retain_mission: Option<String>, pub retain_strategies: Option<Map<String, Value>>, pub tags: Option<Vec<String>>,
}
Request to update an existing template. All fields optional.

Note: cross-field validation (e.g. custom mode requires custom instructions) cannot be fully checked here because this is a partial update. The endpoint must merge with the existing record and validate the final state.

JSON schema
{
 "title": "UpdateTemplateRequest",
 "description": "Request to update an existing template. All fields optional.\n\nNote: cross-field validation (e.g. custom mode requires custom instructions)\ncannot be fully checked here because this is a partial update. The endpoint\nmust merge with the existing record and validate the final state.",
 "type": "object",
 "properties": {
   "author": {
     "title": "Author",
     "type": [
       "string",
       "null"
     ]
   },
   "consolidation_llm_batch_size": {
     "title": "Consolidation Llm Batch Size",
     "type": [
       "integer",
       "null"
     ],
     "exclusiveMinimum": 0.0
   },
   "consolidation_source_facts_max_tokens": {
     "title": "Consolidation Source Facts Max Tokens",
     "type": [
       "integer",
       "null"
     ]
   },
   "consolidation_source_facts_max_tokens_per_observation": {
     "title": "Consolidation Source Facts Max Tokens Per Observation",
     "type": [
       "integer",
       "null"
     ]
   },
   "description": {
     "title": "Description",
     "type": [
       "string",
       "null"
     ]
   },
   "directive_seeds": {
     "title": "Directive Seeds",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "$ref": "#/components/schemas/DirectiveSeed"
     }
   },
   "disposition_empathy": {
     "title": "Disposition Empathy",
     "type": [
       "integer",
       "null"
     ],
     "maximum": 5.0,
     "minimum": 1.0
   },
   "disposition_literalism": {
     "title": "Disposition Literalism",
     "type": [
       "integer",
       "null"
     ],
     "maximum": 5.0,
     "minimum": 1.0
   },
   "disposition_skepticism": {
     "title": "Disposition Skepticism",
     "type": [
       "integer",
       "null"
     ],
     "maximum": 5.0,
     "minimum": 1.0
   },
   "enable_observations": {
     "title": "Enable Observations",
     "type": [
       "boolean",
       "null"
     ]
   },
   "entities_allow_free_form": {
     "title": "Entities Allow Free Form",
     "type": [
       "boolean",
       "null"
     ]
   },
   "entity_labels": {
     "title": "Entity Labels",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "$ref": "#/components/schemas/EntityLabel"
     }
   },
   "mental_model_seeds": {
     "title": "Mental Model Seeds",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "$ref": "#/components/schemas/MentalModelSeed"
     }
   },
   "min_hindclaw_version": {
     "title": "Min Hindclaw Version",
     "type": [
       "string",
       "null"
     ]
   },
   "min_hindsight_version": {
     "title": "Min Hindsight Version",
     "type": [
       "string",
       "null"
     ]
   },
   "observations_mission": {
     "title": "Observations Mission",
     "type": [
       "string",
       "null"
     ]
   },
   "reflect_mission": {
     "title": "Reflect Mission",
     "type": [
       "string",
       "null"
     ]
   },
   "retain_chunk_size": {
     "title": "Retain Chunk Size",
     "type": [
       "integer",
       "null"
     ],
     "exclusiveMinimum": 0.0
   },
   "retain_custom_instructions": {
     "title": "Retain Custom Instructions",
     "type": [
       "string",
       "null"
     ]
   },
   "retain_default_strategy": {
     "title": "Retain Default Strategy",
     "type": [
       "string",
       "null"
     ]
   },
   "retain_extraction_mode": {
     "title": "Retain Extraction Mode",
     "type": [
       "string",
       "null"
     ]
   },
   "retain_mission": {
     "title": "Retain Mission",
     "type": [
       "string",
       "null"
     ]
   },
   "retain_strategies": {
     "title": "Retain Strategies",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": true
   },
   "tags": {
     "title": "Tags",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "string"
     }
   }
 },
 "additionalProperties": false
}

Fields

author: Option<String>consolidation_llm_batch_size: Option<NonZeroU64>consolidation_source_facts_max_tokens: Option<i64>consolidation_source_facts_max_tokens_per_observation: Option<i64>description: Option<String>directive_seeds: Option<Vec<DirectiveSeed>>disposition_empathy: Option<NonZeroU64>disposition_literalism: Option<NonZeroU64>disposition_skepticism: Option<NonZeroU64>enable_observations: Option<bool>entities_allow_free_form: Option<bool>entity_labels: Option<Vec<EntityLabel>>mental_model_seeds: Option<Vec<MentalModelSeed>>min_hindclaw_version: Option<String>min_hindsight_version: Option<String>observations_mission: Option<String>reflect_mission: Option<String>retain_chunk_size: Option<NonZeroU64>retain_custom_instructions: Option<String>retain_default_strategy: Option<String>retain_extraction_mode: Option<String>retain_mission: Option<String>retain_strategies: Option<Map<String, Value>>tags: Option<Vec<String>>